==> jc-1.4.0.tar.gz: soot/toolkits/graph/ZonedBlockGraph.h <==
// public class soot.toolkits.graph.ZonedBlockGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph
// @dep_class db39a1f9e14809d7 soot_toolkits_graph_ZonedBlockGraph

// header file dependencies
// @dep_header soot_toolkits_graph_BlockGraph

#include "soot/toolkits/graph/BlockGraph.h"

#ifndef _JC_soot_toolkits_graph_ZonedBlockGraph_H_
#define _JC_soot_toolkits_graph_ZonedBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs	_jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs	_jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$refs	_jc_soot_toolkits_graph_ZonedBlockGraph$refs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs	_jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$object	_jc_soot_toolkits_graph_ZonedBlockGraph$object;

typedef const struct _jc_soot_toolkits_graph_ZonedBlockGraph$vmethods	_jc_soot_toolkits_graph_ZonedBlockGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtable	_jc_soot_toolkits_graph_ZonedBlockGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtype	_jc_soot_toolkits_graph_ZonedBlockGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_ZonedBlockGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_ZonedBlockGraph$object *, struct _jc_soot_Body$object *);

// Virtual methods structure
struct _jc_soot_toolkits_graph_ZonedBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_BlockGraph$vmethods	soot_toolkits_graph_BlockGraph;
	_jc_soot_toolkits_graph_ZonedBlockGraph$vmethods	soot_toolkits_graph_ZonedBlockGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_ZonedBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$refs {
    _jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs	soot_toolkits_graph_ZonedBlockGraph;
    _jc_soot_toolkits_graph_BlockGraph$sub_refs	soot_toolkits_graph_BlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_BlockGraph$sub_nonrefs	soot_toolkits_graph_BlockGraph;
    _jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs	soot_toolkits_graph_ZonedBlockGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_ZonedBlockGraph$object {
	_jc_soot_toolkits_graph_ZonedBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_ZonedBlockGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_ZonedBlockGraph$vtype _jc_soot_toolkits_graph_ZonedBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_ZonedBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_ZonedBlockGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_ZonedBlockGraph_H_ */

==> jc-1.4.6.tar.gz: soot/toolkits/graph/ZonedBlockGraph.h <==
// public class soot.toolkits.graph.ZonedBlockGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 340ee84e9e1f189d soot_toolkits_graph_BlockGraph
// @dep_class db39a1f9e14809d7 soot_toolkits_graph_ZonedBlockGraph

// header file dependencies
// @dep_header soot_toolkits_graph_BlockGraph

#include "soot/toolkits/graph/BlockGraph.h"

#ifndef _JC_soot_toolkits_graph_ZonedBlockGraph_H_
#define _JC_soot_toolkits_graph_ZonedBlockGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Body$object;

// Typedefs
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs	_jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs	_jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$refs	_jc_soot_toolkits_graph_ZonedBlockGraph$refs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs	_jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs;
typedef struct _jc_soot_toolkits_graph_ZonedBlockGraph$object	_jc_soot_toolkits_graph_ZonedBlockGraph$object;

typedef const struct _jc_soot_toolkits_graph_ZonedBlockGraph$vmethods	_jc_soot_toolkits_graph_ZonedBlockGraph$vmethods;
typedef const struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtable	_jc_soot_toolkits_graph_ZonedBlockGraph$vtable;
typedef const struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtype	_jc_soot_toolkits_graph_ZonedBlockGraph$vtype;

// Constructors
extern void _jc_soot_toolkits_graph_ZonedBlockGraph$method$_init$3a6465c484af9c25(_jc_env *, struct _jc_soot_toolkits_graph_ZonedBlockGraph$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_toolkits_graph_ZonedBlockGraph$vmethods {
};

// Vtable
struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_toolkits_graph_BlockGraph$vmethods	soot_toolkits_graph_BlockGraph;
	_jc_soot_toolkits_graph_ZonedBlockGraph$vmethods	soot_toolkits_graph_ZonedBlockGraph;
};

// Vtype
struct _jc_soot_toolkits_graph_ZonedBlockGraph$vtype {
	_jc_type			type;
	_jc_soot_toolkits_graph_ZonedBlockGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$refs {
    _jc_soot_toolkits_graph_ZonedBlockGraph$sub_refs	soot_toolkits_graph_ZonedBlockGraph;
    _jc_soot_toolkits_graph_BlockGraph$sub_refs	soot_toolkits_graph_BlockGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_toolkits_graph_BlockGraph$sub_nonrefs	soot_toolkits_graph_BlockGraph;
    _jc_soot_toolkits_graph_ZonedBlockGraph$sub_nonrefs	soot_toolkits_graph_ZonedBlockGraph;
};

// Object instance structure
struct _jc_soot_toolkits_graph_ZonedBlockGraph$object {
	_jc_soot_toolkits_graph_ZonedBlockGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_toolkits_graph_ZonedBlockGraph$vtype	*vtype;
	_jc_soot_toolkits_graph_ZonedBlockGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_toolkits_graph_ZonedBlockGraph$vtype _jc_soot_toolkits_graph_ZonedBlockGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_toolkits_graph_ZonedBlockGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_toolkits_graph_ZonedBlockGraph$class_object;

#endif	/* _JC_soot_toolkits_graph_ZonedBlockGraph_H_ */
